@@ -125,10 +125,14 @@ class PackageBuild:
         logging.info('{} clean'.format(self.name))
         run_shell_list([
             'git rm -r --cached .',
-            "tag git tag -l|xargs git tag -d",
+            'git tag -d $(git tag -l) ',  # 删除本地tag
+            'git fetch',  # 拉取远程tag
+            'git push origin --delete $(git tag -l)',  # 删除远程tag
+            "git tag -d $(git tag -l)",  # 删除本地tag
             'git add .',
             "git commit -m 'update .gitignore'",
-            'git gc --aggressive'
+            'git gc --aggressive',
+            'git push'
         ])
 
     def git_tags(self):
